from typing import Optional

from asset_discovery.models import AssetIdentification, Asset
from asset_discovery.repository.data_store import DataStore
from asset_discovery.repository.json_data_store import JsonDataStore
from asset_discovery.util.asset_cache_serializer import AssetCacheSerializer


class AssetCache:
    def __init__(self, data_store: DataStore = None):
        if data_store is None:
            data_store = JsonDataStore(serializer=AssetCacheSerializer())
        self._json_asset_data_store = data_store

    def list_assets(self):
        return self._json_asset_data_store.list()

    def get_by_identification(self, asset_identification: AssetIdentification) -> Optional[Asset]:
        return self._json_asset_data_store.get_by_identification(asset_identification)

    def add_asset(self, asset):
        self._json_asset_data_store.add(asset)

    def remove_asset(self, asset_identification):
        self._json_asset_data_store.remove(asset_identification)

    def empty_cache(self):
        self._json_asset_data_store.remove_all()

    def update_asset(self, asset):
        self._json_asset_data_store.update(asset)
