import os
import logging
import time
from typing import Callable, Any, Dict

import pyinotify

logger = logging.getLogger()


class FileChangedEventHandler(pyinotify.ProcessEvent):
    def my_init(self, handler: Callable[[], Dict[str, Any]], file_extension: str, file_name: str, **kwargs):
        self._handler = handler
        self._file_extension = file_extension
        self._file_name = file_name
        self._last_modified_timestamp = None
        self._event_merge_interval = 2

    def __call__(self, event: pyinotify.Event):
        logger.debug('Discovery Engine - linux_file_monitor event handler called with event ' + str(event.name))
        is_file_match = self._file_name is not None and event.name == self._file_name
        matches_extension = self._file_extension is not None and os.path.splitext(event.name)[1] == self._file_extension
        if is_file_match or matches_extension:
            if event.maskname == 'IN_MODIFY':
                now = time.time()
                if self._should_trigger_modified_event(now):
                    self._last_modified_timestamp = now
                    self._handler()
                else:
                    logger.debug('linux_file_changed_event_handler - suppressed modify event at ' + str(now))
            else:
                self._handler()

    def _should_trigger_modified_event(self, now: time.time):
        return (self._last_modified_timestamp is None or
                (now - self._last_modified_timestamp) >= self._event_merge_interval)
