import pprint

from . import SensorCollection, LifetimePowerOn, OperationalState
from .cooling_health import CoolingHealth


class AssetHealthData:

    property_types = {
        'temperature_sensors': 'SensorCollection',
        'voltage_sensors': 'SensorCollection',
        'power_sensors': 'SensorCollection',
        'cooling_health': 'CoolingHealth',
        'lifetime_power_on': 'LifetimePowerOn',
        'operational_state': 'OperationalState'
    }

    serialization_keys = {
        'temperature_sensors': 'temperatureSensors',
        'voltage_sensors': 'voltageSensors',
        'power_sensors': 'powerSensors',
        'cooling_health': 'coolingHealth',
        'lifetime_power_on': 'lifetimePowerOn',
        'operational_state': 'operationalState'
    }

    def __init__(self,
                 temperature_sensors: SensorCollection = None,
                 voltage_sensors: SensorCollection = None,
                 power_sensors: SensorCollection = None,
                 lifetime_power_on: LifetimePowerOn = None,
                 operational_state: OperationalState = None,
                 cooling_health: CoolingHealth = None):
        self._temperature_sensors = temperature_sensors
        self._voltage_sensors = voltage_sensors
        self._power_sensors = power_sensors
        self._cooling_health = cooling_health
        self._lifetime_power_on = lifetime_power_on
        self._operational_state = operational_state

    @property
    def temperature_sensors(self) -> SensorCollection:
        """Gets the temperature_sensors of this AssetHealthData.

        Temperature sensors of the asset.

        :return: The temperate_sensors of this AssetHealthData.
        :rtype: SensorCollection
        """
        return self._temperature_sensors

    @temperature_sensors.setter
    def temperature_sensors(self, temperate_sensors: SensorCollection) -> None:
        """Sets the temperate_sensors of this AssetHealthData.

        Temperature sensors of the asset.

        :param temperate_sensors: The temperature sensors of this AssetHealthData.
        :type: SensorCollection
        """
        self._temperature_sensors = temperate_sensors

    @property
    def voltage_sensors(self) -> SensorCollection:
        """Gets the voltage sensors of this AssetHealthData.

        Voltage sensors of the asset.

        :return: The voltage sensors of this AssetHealthData.
        :rtype: SensorCollection
        """
        return self._voltage_sensors

    @voltage_sensors.setter
    def voltage_sensors(self, voltage_sensors: SensorCollection) -> None:
        """Sets the voltage sensors of this AssetHealthData.

        Voltage sensors of the asset.

        :param voltage_sensors: The voltage sensors of this AssetHealthData.
        :type: SensorCollection
        """
        self._voltage_sensors = voltage_sensors

    @property
    def power_sensors(self) -> SensorCollection:
        """Gets the power sensors of this AssetHealthData.

        Power sensors of the asset.
        """
        return self._power_sensors

    @power_sensors.setter
    def power_sensors(self, power_sensors: SensorCollection) -> None:
        """Sets the power sensors of this AssetHealthData.

        Power sensors of the asset.

        :param power_sensors: The power sensors of this AssetHealthData.
        :type: SensorCollection
        """
        self._power_sensors = power_sensors

    @property
    def cooling_health(self) -> CoolingHealth:
        """
        Gets the cooling health of this AssetHealthData.

        Fan sensors of the asset.

        """
        return self._cooling_health

    @cooling_health.setter
    def cooling_health(self, cooling_health: CoolingHealth) -> None:
        """Sets the cooling health of this AssetHealthData.

        Fan sensors of the asset.

        :param cooling_health: The cooling health of this AssetHealthData.
        :type: CoolingHealth
        """
        self._cooling_health = cooling_health

    @property
    def lifetime_power_on(self) -> LifetimePowerOn:
        """Gets the lifetime power on hours of this AssetHealthData.

        Lifetime power on hours of the asset.

        :return: The lifetime power on hours of this AssetHealthData.
        :type: LifetimePowerOn
        """
        return self._lifetime_power_on

    @lifetime_power_on.setter
    def lifetime_power_on(self, lifetime_power_on: LifetimePowerOn) -> None:
        """Sets the lifetime power on hours of this AssetHealthData.

        Lifetime power on hours of the asset.

        :param lifetime_power_on: The lifetime power on hours of this AssetHealthData.
        :type: LifetimePowerOnHours
        """
        self._lifetime_power_on = lifetime_power_on

    @property
    def operational_state(self) -> OperationalState:
        """Gets the operational state of this AssetHealthData.

        Operational state of the asset.

        :return: The operational state of this AssetHealthData.
        :type: OperationalState
        """
        return self._operational_state

    @operational_state.setter
    def operational_state(self, operational_state: OperationalState) -> None:
        """Sets the operational state of this AssetHealthData.

        Operational state of the asset.

        :param operational_state: The operational state of this AssetHealthData.
        :type: OperationalState
        """
        self._operational_state = operational_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.property_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetHealthData):
            return False

        return (self.temperature_sensors == other.temperature_sensors and
                self.voltage_sensors == other.voltage_sensors and
                self.power_sensors == other.power_sensors and
                self.cooling_health == other.cooling_health and
                self.lifetime_power_on == other.lifetime_power_on and
                self.operational_state == other.operational_state)

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self.__eq__(other)
