# coding: utf-8
"""
    Model representing an external calibration.
"""

import pprint


class ExternalCalibration:
    """
    Model representing an external calibration.
    """
    property_types = {
        'temperature_sensors': 'list[TemperatureSensor]',
        'is_limited': 'bool',
        'date': 'datetime',
        'recommended_interval': 'int',
        'next_recommended_date': 'datetime',
        'next_custom_due_date': 'datetime',
        'comments': 'str',
        'entry_type': 'CalibrationMode',
        'operator': 'CalibrationOperator',
        'checksum': 'str'
    }

    serialization_keys = {
        'temperature_sensors': 'temperatureSensors',
        'is_limited': 'isLimited',
        'date': 'date',
        'recommended_interval': 'recommendedInterval',
        'next_recommended_date': 'nextRecommendedDate',
        'next_custom_due_date': 'nextCustomDueDate',
        'comments': 'comments',
        'entry_type': 'entryType',
        'operator': 'operator',
        'checksum': 'checksum'
    }

    def __init__(self,
                 temperature_sensors=None,
                 is_limited=None,
                 date=None,
                 recommended_interval=None,
                 next_recommended_date=None,
                 next_custom_due_date=None,
                 comments=None,
                 entry_type=None,
                 operator=None,
                 checksum=None):
        self._temperature_sensors = None
        self._is_limited = None
        self._date = None
        self._recommended_interval = None
        self._next_recommended_date = None
        self._next_custom_due_date = None
        self._comments = None
        self._entry_type = None
        self._operator = None
        self._checksum = None

        self.temperature_sensors = temperature_sensors
        if is_limited is not None:
            self.is_limited = is_limited
        self.date = date
        self.recommended_interval = recommended_interval
        self.next_recommended_date = next_recommended_date
        if next_custom_due_date is not None:
            self.next_custom_due_date = next_custom_due_date
        if comments is not None:
            self.comments = comments
        if entry_type is not None:
            self.entry_type = entry_type
        if operator is not None:
            self.operator = operator
        if checksum is not None:
            self.checksum = checksum

    @property
    def temperature_sensors(self):
        """Gets the temperature_sensors of this ExternalCalibration.

        An array of temperature sensor information.

        :return: The temperature_sensors of this ExternalCalibration.
        :rtype: list[TemperatureSensor]
        """
        return self._temperature_sensors

    @temperature_sensors.setter
    def temperature_sensors(self, temperature_sensors):
        """Sets the temperature_sensors of this ExternalCalibration.

        An array of temperature sensor information.

        :param temperature_sensors: The temperature_sensors of this ExternalCalibration.
        :type: list[TemperatureSensor]
        """
        self._temperature_sensors = temperature_sensors

    @property
    def is_limited(self):
        """Gets the is_limited of this ExternalCalibration.

        Whether the last external calibration of the asset was a limited calibration.

        :return: The is_limited of this ExternalCalibration.
        :rtype: bool
        """
        return self._is_limited

    @is_limited.setter
    def is_limited(self, is_limited):
        """Sets the is_limited of this ExternalCalibration.

        Whether the last external calibration of the asset was a limited calibration.

        :param is_limited: The is_limited of this ExternalCalibration.
        :type: bool
        """

        self._is_limited = is_limited

    @property
    def date(self):
        """Gets the date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the last date the asset was externally calibrated.

        :return: The date of this ExternalCalibration.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the last date the asset was externally calibrated.

        :param date: The date of this ExternalCalibration.
        :type: datetime
        """
        self._date = date

    @property
    def recommended_interval(self):
        """Gets the recommended_interval of this ExternalCalibration.

        The manufacturer's recommended calibration interval in months.

        :return: The recommended_interval of this ExternalCalibration.
        :rtype: int
        """
        return self._recommended_interval

    @recommended_interval.setter
    def recommended_interval(self, recommended_interval):
        """Sets the recommended_interval of this ExternalCalibration.

        The manufacturer's recommended calibration interval in months.

        :param recommended_interval: The recommended_interval of this ExternalCalibration.
        :type: int
        """
        self._recommended_interval = recommended_interval

    @property
    def next_recommended_date(self):
        """Gets the next_recommended_date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the recommended date for the next external calibration.

        :return: The next_recommended_date of this ExternalCalibration.
        :rtype: datetime
        """
        return self._next_recommended_date

    @next_recommended_date.setter
    def next_recommended_date(self, next_recommended_date):
        """Sets the next_recommended_date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the recommended date for the next external calibration.

        :param next_recommended_date: The next_recommended_date of this ExternalCalibration.
        :type: datetime
        """
        self._next_recommended_date = next_recommended_date

    @property
    def next_custom_due_date(self):
        """Gets the next_custom_due_date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the date for the next external calibration.

        :return: The next_custom_due_date of this ExternalCalibration.
        :rtype: datetime
        """
        return self._next_custom_due_date

    @next_custom_due_date.setter
    def next_custom_due_date(self, next_custom_due_date):
        """Sets the next_custom_due_date of this ExternalCalibration.

        ISO-8601 formatted timestamp specifying the date for the next external calibration.

        :param next_custom_due_date: The next_custom_due_date of this ExternalCalibration.
        :type: datetime
        """

        self._next_custom_due_date = next_custom_due_date

    @property
    def comments(self):
        """Gets the comments of this ExternalCalibration.

        Calibration comments provided by an operator.

        :return: The comments of this ExternalCalibration.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this ExternalCalibration.

        Calibration comments provided by an operator.

        :param comments: The comments of this ExternalCalibration.
        :type: str
        """

        self._comments = comments

    @property
    def entry_type(self):
        """Gets the entry_type of this ExternalCalibration.


        :return: The entry_type of this ExternalCalibration.
        :rtype: CalibrationMode
        """
        return self._entry_type

    @entry_type.setter
    def entry_type(self, entry_type):
        """Sets the entry_type of this ExternalCalibration.


        :param entry_type: The entry_type of this ExternalCalibration.
        :type: CalibrationMode
        """

        self._entry_type = entry_type

    @property
    def operator(self):
        """Gets the operator of this ExternalCalibration.


        :return: The operator of this ExternalCalibration.
        :rtype: CalibrationOperator
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this ExternalCalibration.


        :param operator: The operator of this ExternalCalibration.
        :type: CalibrationOperator
        """

        self._operator = operator

    @property
    def checksum(self):
        """Gets the checksum of this ExternalCalibration.

        Checksum for the external calibration.

        :return: The checksum of this ExternalCalibration.
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this ExternalCalibration.

        Checksum for the external calibration.

        :param checksum: The checksum of this ExternalCalibration.
        :type: str
        """

        self._checksum = checksum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.property_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalCalibration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self.__eq__(other)
