# coding: utf-8
"""
    Model representing a self-calibration.
"""

import pprint


class SelfCalibration:
    """
    Model representing a self-calibration.
    """
    property_types = {
        'temperature_sensors': 'list[TemperatureSensor]',
        'is_limited': 'bool',
        'date': 'datetime'
    }

    serialization_keys = {
        'temperature_sensors': 'temperatureSensors',
        'is_limited': 'isLimited',
        'date': 'date'
    }

    def __init__(self,
                 temperature_sensors=None,
                 is_limited=None,
                 date=None):
        self._temperature_sensors = None
        self._is_limited = None
        self._date = None

        if temperature_sensors is not None:
            self.temperature_sensors = temperature_sensors
        if is_limited is not None:
            self.is_limited = is_limited
        self.date = date

    @property
    def temperature_sensors(self):
        """Gets the temperature_sensors of this SelfCalibration.

        An array of temperature sensor information.

        : return: The temperature_sensors of this SelfCalibration.
        : rtype: list[TemperatureSensor]
        """
        return self._temperature_sensors

    @temperature_sensors.setter
    def temperature_sensors(self, temperature_sensors):
        """Sets the temperature_sensors of this SelfCalibration.

        An array of temperature sensor information.

        : param temperature_sensors: The temperature_sensors of this SelfCalibration.
        : type: list[TemperatureSensor]
        """

        self._temperature_sensors = temperature_sensors

    @property
    def is_limited(self):
        """Gets the is_limited of this SelfCalibration.

        Whether the last self-calibration of the asset was a limited calibration.

        : return: The is_limited of this SelfCalibration.
        : rtype: bool
        """
        return self._is_limited

    @is_limited.setter
    def is_limited(self, is_limited):
        """Sets the is_limited of this SelfCalibration.

        Whether the last self-calibration of the asset was a limited calibration.

        : param is_limited: The is_limited of this SelfCalibration.
        : type: bool
        """

        self._is_limited = is_limited

    @property
    def date(self):
        """Gets the date of this SelfCalibration.

        ISO-8601 formatted timestamp specifying the last date the asset was self-calibrated.

        : return: The date of this SelfCalibration.
        : rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this SelfCalibration.

        ISO-8601 formatted timestamp specifying the last date the asset was self-calibrated.

        : param date: The date of this SelfCalibration.
        : type: datetime
        """
        self._date = date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.property_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SelfCalibration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self.__eq__(other)
