# coding: utf-8
"""
    Model for a temperature sensor.
"""

import pprint


class TemperatureSensor:
    """
    Model for a temperature sensor.
    """

    """
    Attributes:
      property_types (dict): The key is attribute name
                            and the value is attribute type.
      serialization_keys (dict): The key is attribute name
                            and the value is json key in definition.
    """
    property_types = {
        'name': 'str',
        'reading': 'float'
    }

    serialization_keys = {
        'name': 'name',
        'reading': 'reading'
    }

    def __init__(self, name=None, reading=None):
        self._name = None
        self._reading = None

        if name is not None:
            self.name = name
        self.reading = reading

    @property
    def name(self):
        """Gets the name of this TemperatureSensor.

        Sensor name

        :return: The name of this TemperatureSensor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TemperatureSensor.

        Sensor name

        :param name: The name of this TemperatureSensor.
        :type: str
        """

        self._name = name

    @property
    def reading(self):
        """Gets the reading of this TemperatureSensor.

        Sensor reading

        :return: The reading of this TemperatureSensor.
        :rtype: float
        """
        return self._reading

    @reading.setter
    def reading(self, reading):
        """Sets the reading of this TemperatureSensor.

        Sensor reading

        :param reading: The reading of this TemperatureSensor.
        :type: float
        """
        self._reading = reading

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.property_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemperatureSensor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self.__eq__(other)
