from asset_discovery.models.sensor_properties import SensorProperties
from asset_discovery.models.sensor_type import SensorType
from asset_discovery.plugins.sysapi_imports.repository.base_sensor_attributes import BaseSensorAttributes
from asset_discovery.plugins.sysapi_imports.repository.base_sensor_serializer import AbstractSensorSerializer
from asset_discovery.plugins.sysapi_imports.repository.models import AttributeTag


class VoltageSensorSerializer(AbstractSensorSerializer):
    def __init__(self):
        super().__init__(numeric_attribute_tags=VoltageSensorSerializer._get_voltage_numeric_attribute_tags(),
                         base_name="Volt",
                         sensor_type=SensorType.VOLTAGE)

    @staticmethod
    def _get_voltage_numeric_attribute_tags():
        return BaseSensorAttributes(
            count=AttributeTag.SensorVoltCount,
            name0=AttributeTag.SensorVoltName0,
            reading0=AttributeTag.SensorVoltReading0,
            upper_critical0=AttributeTag.SensorVoltUpperCritical0,
            health_state0=AttributeTag.SensorVoltHealthState0,
            upper_damage_risk0=AttributeTag.SensorVoltUpperDamageRisk0,
            upper_user0=AttributeTag.SensorVoltUpperUser0,
            alarm0=AttributeTag.SensorVoltAlarm0,
            accuracy0=AttributeTag.SensorVoltAccuracy0,
            polling_interval0=AttributeTag.SensorVoltAlarmPollingInterval0
        )

    def _on_sensor_parsing(self, i, bag, base_sensor):
        nominal = bag.get_property_or_default(AttributeTag.SensorVoltNominal0 + i, None)
        lower_critical = bag.get_property_or_default(AttributeTag.SensorVoltLowerCritical0 + i, None)
        lower_damage_risk = bag.get_property_or_default(AttributeTag.SensorVoltLowerDamageRisk0 + i, None)
        lower_user = bag.get_property_or_default(AttributeTag.SensorVoltLowerUser0 + i, None)

        if nominal is not None:
            base_sensor.properties[SensorProperties.Nominal] = nominal
        if lower_critical is not None:
            base_sensor.properties[SensorProperties.LowerCritical] = lower_critical
        if lower_damage_risk is not None:
            base_sensor.properties[SensorProperties.LowerRisk] = lower_damage_risk
        if lower_user is not None:
            base_sensor.properties[SensorProperties.LowerUser] = lower_user

        return base_sensor
