from typing import Any, Dict
from datetime import datetime

from asset_discovery.models import Asset, AssetMetadata
from asset_discovery.models.discovery_type import DiscoveryType
from asset_discovery.util.asset_serializer import AssetSerializer
from asset_discovery.util import asset_serializer_constants


class AssetCacheSerializer(AssetSerializer):
    DISCOVERY_TYPE_VALUES = {
        'AUTOMATIC': DiscoveryType.AUTOMATIC,
        'Automatic': DiscoveryType.AUTOMATIC,
        'MANUAL': DiscoveryType.MANUAL,
        'Manual': DiscoveryType.MANUAL
    }

    def _set_handled_properties_on_asset(self, properties, asset):
        super(AssetCacheSerializer, self)._set_handled_properties_on_asset(properties, asset)

        discovery_type_property = properties.get(asset_serializer_constants.DISCOVERY_TYPE_KEY, None)
        discovery_type = self.DISCOVERY_TYPE_VALUES.get(discovery_type_property, None)
        asset.discovery_type = discovery_type
        self._set_metadata_on_asset(properties, asset)

    def _set_metadata_on_asset(self, properties: Dict[str, Any], asset: Asset):
        metadata_raw = properties.get(asset_serializer_constants.METADATA_KEY, None)
        if not self._isdict(metadata_raw):
            return

        timestamp_str = metadata_raw.get(asset_serializer_constants.METADATA_LAST_UPDATED_TIMESTAMP_KEY, None)
        timestamp = self._parse_date(timestamp_str)
        if not timestamp:
            timestamp = datetime.utcnow()

        version = metadata_raw.get(asset_serializer_constants.METADATA_VERSION_KEY, None)
        if not self._isint(version):
            version = 1

        data_sources_raw = metadata_raw.get(asset_serializer_constants.METADATA_DATA_SOURCES_KEY, None)
        data_sources = []
        if self._islist(data_sources_raw):
            data_sources = [d for d in data_sources_raw if self._isstr(d)]

        metadata = AssetMetadata(
            data_sources=data_sources,
            last_updated_timestamp=timestamp,
            version=version,
            asset_identification=asset.identification  # TODO: This will be removed
        )
        asset.metadata = metadata
